:mod:`animanager.files` --- File related tools
==============================================

.. automodule:: animanager.files

:mod:`animanager.files.anime` --- Anime files
---------------------------------------------

.. automodule:: animanager.files.anime
   :members:

:mod:`animanager.files.picker` --- File picking
-----------------------------------------------

.. automodule:: animanager.files.picker
   :members:

:mod:`animanager.files.utils` --- File utilities
------------------------------------------------

.. automodule:: animanager.files.utils
   :members:
